==> mozc_1.11.1522.102.orig.tar.bz2: mozc-1.11.1522.102/dictionary/file/dictionary_file_builder.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_DICTIONARY_FILE_DICTIONARY_FILE_BUILDER_H_
#define MOZC_DICTIONARY_FILE_DICTIONARY_FILE_BUILDER_H_

#include <set>
#include <string>
#include <vector>

#include "base/base.h"
#include "dictionary/file/section.h"

namespace mozc {
class DictionaryFileBuilder {
 public:
  DictionaryFileBuilder();

  virtual ~DictionaryFileBuilder();

  // Add section from file
  bool AddSectionFromFile(const string &section_name,
                          const string &file_name);

  // Write image of dictionary file to file
  void WriteImageToFile(const string &file_name) const;

 private:
  vector<DictionaryFileSection> sections_;
  set<string> added_;

  DISALLOW_COPY_AND_ASSIGN(DictionaryFileBuilder);
};
}  // namespace mozc

#endif  // MOZC_DICTIONARY_FILE_DICTIONARY_FILE_BUILDER_H_

==> mozc_1.12.1599.102.orig.tar.bz2: mozc-1.12.1599.102/dictionary/file/dictionary_file_builder.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_DICTIONARY_FILE_DICTIONARY_FILE_BUILDER_H_
#define MOZC_DICTIONARY_FILE_DICTIONARY_FILE_BUILDER_H_

#include <set>
#include <string>
#include <vector>

#include "base/port.h"
#include "dictionary/file/section.h"

namespace mozc {
class DictionaryFileBuilder {
 public:
  DictionaryFileBuilder();

  virtual ~DictionaryFileBuilder();

  // Add section from file
  bool AddSectionFromFile(const string &section_name,
                          const string &file_name);

  // Write image of dictionary file to file
  void WriteImageToFile(const string &file_name) const;

 private:
  vector<DictionaryFileSection> sections_;
  set<string> added_;

  DISALLOW_COPY_AND_ASSIGN(DictionaryFileBuilder);
};
}  // namespace mozc

#endif  // MOZC_DICTIONARY_FILE_DICTIONARY_FILE_BUILDER_H_
